==> MeUtils-2023.4.23.18.56.48-py3-none-any.whl: meutils/nlp_utils/ner.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : pos_tagging
# @Time         : 2023/4/23 12:28
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from paddlenlp import Taskflow


class Ner(object):

    def __init__(self, mode='fast', batch_size=8, entity_only=False, device=None, filter_func=None):
        """

        :param mode:
            fast lac
            accurate 解语
        :param filter_func: lambda word, flag: flag.startswith(('n', 'PER', 'LOC', 'ORG', 'TIME'))
        :param batch_size:
        :param entity_only:
        :param device:
        """
        self.batch_size = batch_size
        self.filter_func = filter_func
        self.task_flow = Taskflow(
            task='ner',
            mode=mode,
            device=device,
            batch_size=batch_size,
            entity_only=entity_only
        )

    def __call__(self, *texts):
        if isinstance(texts, str):
            texts = [texts]
        results = texts[0] | xbar4iter(self.task_flow, self.batch_size)
        if self.filter_func:
            return  results | xfilter_(self.filter_func)

        return results

    def nptag(self):  # todo: PER	人名	LOC	地名	ORG	机构名	TIME	时间 增加过滤机制
        pass

    # def get_words(text):
    #     ws = []
    #     for w, flag in cut(text):
    #         if flag.startswith(('n', 'PER', 'LOC', 'ORG', 'TIME')) and w not in SW:
    #             ws.append(w)
    #     return ws

    # 名词标注 https://github.com/PaddlePaddle/PaddleNLP/blob/develop/docs/model_zoo/taskflow.md#%E8%A7%A3%E8%AF%AD%E7%9F%A5%E8%AF%86%E6%A0%87%E6%B3%A8
    # >>> from paddlenlp import Taskflow
    # >>> nptag = Taskflow("knowledge_mining", model="nptag")
    # >>> nptag("糖醋排骨")
    # [{'text': '糖醋排骨', 'label': '菜品'}]


if __name__ == '__main__':
    print(Ner('accurate')(['周杰伦是个音乐家'] * 10))
    print(Ner('fast')(['周杰伦是个音乐家'] * 10))

==> MeUtils-2023.4.23.19.7.51-py3-none-any.whl: meutils/nlp_utils/ner.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : pos_tagging
# @Time         : 2023/4/23 12:28
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from paddlenlp import Taskflow


class Ner(object):

    def __init__(self, mode='fast', batch_size=8, entity_only=False, device=None, filter_func=None):
        """

        :param mode:
            fast lac
            accurate 解语
        :param filter_func: lambda w2t: w2t[1].startswith(('n', 'PER')) # word2tag
        :param batch_size:
        :param entity_only:
        :param device:
        """
        self.batch_size = batch_size
        self.filter_func = filter_func

        self.task_flow = Taskflow(
            task='ner',
            mode=mode,
            device=device,
            batch_size=batch_size,
            entity_only=entity_only
        )

    def __call__(self, *texts):
        if isinstance(texts, str):
            texts = [texts]

        results = texts[0] | xbar4iter(self.task_flow, self.batch_size)
        if self.filter_func:  # 每一条都过滤
            return results | xmap_(lambda w2ts: w2ts | xfilter_(self.filter_func))  # todo 简化下逻辑
        return results

    # 名词标注 https://github.com/PaddlePaddle/PaddleNLP/blob/develop/docs/model_zoo/taskflow.md#%E8%A7%A3%E8%AF%AD%E7%9F%A5%E8%AF%86%E6%A0%87%E6%B3%A8
    # >>> from paddlenlp import Taskflow
    # >>> nptag = Taskflow("knowledge_mining", model="nptag")
    # >>> nptag("糖醋排骨")
    # [{'text': '糖醋排骨', 'label': '菜品'}]


if __name__ == '__main__':
    print(Ner('accurate')(['周杰伦是个音乐家'] * 10))
    print(Ner('fast')(['周杰伦是个音乐家'] * 10))
